@@ -52,7 +52,7 @@ public:
     AIEntity* createAI(Sea::Player player, SeaView* view);
     NetworkEntity* createRemotePlayer(Sea::Player player, SeaView* view, Protocol* protocol, bool client);
 
-    bool start(SeaView* view, bool ask = false);
+    bool start(SeaView* view);
     Entity* findEntity(Sea::Player) const;
     Sea::Player turn() const;
     bool hasAI() const;
@@ -62,12 +62,12 @@ public:
 public slots:
     void shoot(int player, const Coord& c);
     void ready(int player);
-    void shipsPlaced(int player);
+    void shipsPlaced();
     void receivedChat(const QString& text);
     void nick(int player, const QString& nick);
     void notifyRestartPlacingShips(Sea::Player player);
-    void placing(bool ask = false);
-    void restart(bool ask = false);
+    void placing();
+    void restart();
 signals:
     void gameOver(Sea::Player);
     void restartRequested();
